
# Type: inlined


an inlined definition a list of actual values rather than references.  Only applies to slots whose range is a class.

URI: [meta:inlined](https://w3id.org/biolink/biolinkml/meta/inlined)


## Domain and Range

[SlotDefinition](SlotDefinition.md) ->  <sub>OPT</sub> [Boolean](types/Boolean.md)

## Parents


## Children


## Used by

 * [SlotDefinition](SlotDefinition.md)
